/*
 *  OpenVPN-GUI -- A Windows GUI for OpenVPN.
 *
 *  Copyright (C) 2004 Mathias Sundman <mathias@nilings.se>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program (see the file COPYING included with this
 *  distribution); if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <windows.h>
#include "main.h"
#include "options.h"
#include "passphrase.h"
#include "openvpn-gui-res.h"

void ShowChangePassphraseDialog(int config)
{
  HANDLE hThread; 
  DWORD IDThread; 

  /* Start a new thread to have our own message-loop for this dialog */
  hThread = CreateThread(NULL, 0, 
            (LPTHREAD_START_ROUTINE) ChangePassphraseThread,
            (int *) config,  // pass config nr
            0, &IDThread); 
  if (hThread == NULL) 
    {
    ShowMsg (GUI_NAME, "CreateThread to show ChangePassphrase dialog failed.");
    return;
  }

}

void ChangePassphraseThread(int config)
{
  extern struct options o;
  HWND hwndChangePSW;
  MSG messages;            /* Here messages to the application are saved */

  /* Show Status Dialog */  
  if (!(hwndChangePSW = CreateDialog (o.hInstance, 
        MAKEINTRESOURCE (IDD_CHANGEPSW),
        NULL, (DLGPROC) ChangePassphraseDialogFunc)))
    return;
//  SetDlgItemText(o.cnn[config].hwndStatus, TEXT_STATUS, "Current State: Connecting"); 
  SetDlgItemInt(hwndChangePSW, TEXT_CONFIG, config, FALSE);
  ShowWindow(hwndChangePSW, SW_SHOW);


  /* Run the message loop. It will run until GetMessage() returns 0 */
  while (GetMessage (&messages, NULL, 0, 0))
    {
      if(!IsDialogMessage(hwndChangePSW, &messages))
      {
        TranslateMessage(&messages);
        DispatchMessage(&messages);
      }
    }

  ExitThread(0);
}

BOOL CALLBACK ChangePassphraseDialogFunc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lParam)
{
  HICON hIcon;

  switch (msg) {

    case WM_INITDIALOG:
      hIcon = (HICON)LoadImage(GetModuleHandle(NULL), MAKEINTRESOURCE(APP_ICON), 
                                                      IMAGE_ICON, 0, 0, LR_DEFAULTCOLOR);
      if (hIcon) {
        SendMessage(hwndDlg, WM_SETICON, (WPARAM) (ICON_SMALL), (LPARAM) (hIcon));
        SendMessage(hwndDlg, WM_SETICON, (WPARAM) (ICON_BIG), (LPARAM) (hIcon));
      }
      return FALSE;

    case WM_COMMAND:
      switch (LOWORD(wParam)) {

        case IDOK:			// button
          //GetDlgItemText(hwndDlg, EDIT_PASSPHRASE, passphrase, sizeof(passphrase) - 1);
          ShowMsg(GUI_NAME, "Change PSW");
          DestroyWindow(hwndDlg);       
          break;

        case IDCANCEL:			// button
          DestroyWindow(hwndDlg);       
          break;
      }
      break;

    case WM_DESTROY: 
      PostQuitMessage(0); 
      break; 


    case WM_CLOSE:
      DestroyWindow(hwndDlg);       
      return FALSE;
     
  }
  return FALSE;
}
